@@ -1,6 +1,6 @@
 from __future__ import annotations
 import warnings
-from typing import TypedDict, Any
+import typing as t
 from functools import cached_property
 from cryptography.hazmat.primitives.asymmetric.rsa import (
     generate_private_key,
@@ -13,7 +13,6 @@ from cryptography.hazmat.primitives.asymmetric.rsa import (
     rsa_crt_dmq1,
     rsa_crt_iqmp,
 )
-from cryptography.hazmat.backends import default_backend
 from ..registry import KeyParameter
 from ..errors import SecurityWarning, KeyParameterError
 from .._rfc7517.models import AsymmetricKey
@@ -22,7 +21,7 @@ from .._rfc7517.types import KeyParameters, AnyKey
 from ..util import int_to_base64, base64_to_int
 
 
-RSADictKey = TypedDict(
+RSADictKey = t.TypedDict(
     "RSADictKey",
     {
         "n": str,
@@ -43,6 +42,10 @@ class RSABinding(CryptographyBinding):
     ssh_type = b"ssh-rsa"
     _cryptography_key_types = (RSAPrivateKey, RSAPublicKey)
 
+    @staticmethod
+    def generate_private_key(size: int) -> RSAPrivateKey:
+        return generate_private_key(public_exponent=65537, key_size=size)
+
     @staticmethod
     def import_private_key(obj: RSADictKey) -> RSAPrivateKey:
         if "oth" in obj:  # pragma: no cover
@@ -74,7 +77,7 @@ class RSABinding(CryptographyBinding):
                 public_numbers=public_numbers,
             )
 
-        return numbers.private_key(default_backend())
+        return numbers.private_key()
 
     @staticmethod
     def export_private_key(key: RSAPrivateKey) -> RSADictKey:
@@ -93,7 +96,7 @@ class RSABinding(CryptographyBinding):
     @staticmethod
     def import_public_key(obj: RSADictKey) -> RSAPublicKey:
         numbers = RSAPublicNumbers(base64_to_int(obj["e"]), base64_to_int(obj["n"]))
-        return numbers.public_key(default_backend())
+        return numbers.public_key()
 
     @staticmethod
     def export_public_key(key: RSAPublicKey) -> dict[str, str]:
@@ -136,12 +139,16 @@ class RSAKey(AsymmetricKey[RSAPrivateKey, RSAPublicKey]):
 
     @classmethod
     def import_key(
-        cls: Any,
-        value: AnyKey,
+        cls: t.Any,
+        value: AnyKey | RSAPrivateKey | RSAPublicKey,
         parameters: KeyParameters | None = None,
-        password: Any = None,
+        password: t.Any = None,
     ) -> "RSAKey":
-        key: RSAKey = super(RSAKey, cls).import_key(value, parameters, password)
+        key: RSAKey
+        if isinstance(value, (RSAPrivateKey, RSAPublicKey)):
+            key = cls(value, value, parameters)
+        else:
+            key = super(RSAKey, cls).import_key(value, parameters, password)
         if key.raw_value.key_size < 2048:
             # https://csrc.nist.gov/publications/detail/sp/800-131a/rev-2/final
             warnings.warn("Key size should be >= 2048 bits", SecurityWarning)
@@ -149,7 +156,7 @@ class RSAKey(AsymmetricKey[RSAPrivateKey, RSAPublicKey]):
 
     @classmethod
     def generate_key(
-        cls,
+        cls: t.Type["RSAKey"],
         key_size: int | None = 2048,
         parameters: KeyParameters | None = None,
         private: bool = True,
@@ -166,17 +173,13 @@ class RSAKey(AsymmetricKey[RSAPrivateKey, RSAPublicKey]):
             key_size = 2048
 
         if key_size % 8 != 0:
-            raise ValueError("Invalid key_size for RSAKey")
+            raise ValueError("A bit size must be a multiple of 8")
 
         if key_size < 2048:
             # https://csrc.nist.gov/publications/detail/sp/800-131a/rev-2/final
             warnings.warn("Key size should be >= 2048 bits", SecurityWarning)
 
-        raw_key = generate_private_key(
-            public_exponent=65537,
-            key_size=key_size,
-            backend=default_backend(),
-        )
+        raw_key = cls.binding.generate_private_key(key_size)
         if private:
             key = cls(raw_key, raw_key, parameters)
         else:
